function varargout = ciplot(varargin)
%
%CIPLOT - plot confidence intervals as shaded area
%
% function hPatch = ciplot(lower,upper [,timeScale, colour])
%
% The function plots a confidence interval, or rather
% any interval, defined by lower/upper as a shaded 
% area - a patch object. The patch handle is returned to
% the caller. Alpha is set to .2 (see-through). Further 
% the egdes are faded out. 
% Change this with >> set(hPatch,'EdgeAlpha',0)
%
% The area will be added by to the plot. It won't clear
% any existing object. 
%
% Input:
%	upper = upper bounds (vector)
%	lower = lower bounds (vector)
%	tScale = time scale
%	colour = colour of the area 
%
% requires: 
%
% see also: 
%

% Copyright (C) 2009 Stefan Schinkel, University of Potsdam
% http://www.agnld.uni-potsdam.de 
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

% $Log$

%% I/O check
if (nargchk(2,4,nargin)), help(mfilename),error(nargchk(2,3,nargin)); end
if (nargchk(0,1,nargout)), help(mfilename),error(nargchk(0,1,nargout)); end

varargin{5} = [];

upperBound = varargin{1};
lowerBound = varargin{2};
if isempty(varargin{3}); tScale = 1:length(upperBound); else tScale = varargin{3};end
if isempty(varargin{4}), colour = [.7 .7 .7]; else colour = varargin{4};end


% size check
if length(size(upperBound)) > 2 || length(size(lowerBound)) > 2
	error('Lower and upper must be vectors.')
end
if length(lowerBound)~=length(upperBound)
    error('Lower and upper must be vectors of the same length.')
end


% ensure upper & lower are row vectors
upperBound = upperBound(:)';
lowerBound = lowerBound(:)';



%make sure we don't overwrite things
if ~ishold(gca),
	set(gca,'NextPlot','add');
end

% create the patch  - NOTE: x(end:-1:1) == fliplr(x) 
hPatch = fill([tScale tScale(end:-1:1)], [upperBound lowerBound(end:-1:1)],colour);

% hide edges
set(hPatch,'EdgeAlpha',0);

% make it see-through
alpha(hPatch,.2)

if nargout
	varargout{1} = hPatch;
end
